@@ -3,13 +3,12 @@
 global $blocked;
 
 $virusscan = 1;
+$virusscanupdate = 1;
 
-$excluded = Array('jimmy@advcs.org');
+$excluded = Array('');
 
 $blocked = Array('bat',
 'com',
-'js',
-'mp3',
 'pif',
 'scr',
 'vbs');
