@@ -5,16 +5,21 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Block Attachments
-    Version ........ 0.3
+    Version ........ 0.4
     Purpose ........ Allows an admin to block any types of attachments
 
 *******************************************************************************/
 
    global $optpage_blocks, $username;
+   $admins = array();
+   $file = fopen(SM_PATH . 'config/admins',r);
+   while (!feof($file)){
+      $x = trim(fgets($file));
+      if (strlen($x)>0)
+         $admins[]= $x;
+   }
 
-   if (!function_exists('adm_check_user'))
-      include_once(SM_PATH . 'plugins/block_attach/includes/auth.php');
-   $auth = adm_check_user();
+   $auth = in_array($username, $admins);
    if (!$auth) return;
    bindtextdomain('block_attach', SM_PATH . 'plugins/block_attach/locale');
    textdomain('block_attach');
