@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Block Attachments
-    Version ........ 0.3
+    Version ........ 0.4
     Purpose ........ Allows an admin to block any types of attachments
 
 *******************************************************************************/
@@ -15,7 +15,7 @@
          $exu = strtolower(strip_tags($_POST['exu']));
          if (strlen($exu) > 0 && !in_array($exu,$excluded)) {
             $excluded[] = $exu;
-            CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$filename);
+            CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$virusscanupdate,$filename);
             Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
          }
       }
@@ -33,11 +33,11 @@
          }
          if (strlen($newb) > 0 && !in_array($newb,$blocked) && !in_array($newb,$warning) && $give == "block") {
             $blocked[] = $newb;
-            CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$filename);
+            CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$virusscanupdate,$filename);
          }
          if (strlen($newb) > 0 && !in_array($newb,$blocked) && !in_array($newb,$warning) && $give == "warning") {
             $warning[] = $newb;
-            CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$filename);
+            CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$virusscanupdate,$filename);
          }
          Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
       }
@@ -48,7 +48,7 @@
             if ($blocked[$a] == $btypes)
                unset($blocked[$a]);
          }
-         CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$filename);
+         CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$virusscanupdate,$filename);
          Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
       }
 
@@ -58,7 +58,7 @@
             if ($warning[$a] == $wtypes)
                unset($warning[$a]);
          }
-         CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$filename);
+         CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$virusscanupdate,$filename);
          Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
       }
 
@@ -68,13 +68,19 @@
             if ($excluded[$a] == $exclude)
                unset($excluded[$a]);
          }
-         CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$filename);
+         CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$virusscanupdate,$filename);
          Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
       }
 
       if (isset($_POST['vscan'])) {
          $vscan = strip_tags($_POST['vscan']);
-         CreateBlockedArray($blocked,$warning,$excluded,$vscan,$filename);
+         CreateBlockedArray($blocked,$warning,$excluded,$vscan,$virusscanupdate,$filename);
+         Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
+      }
+
+      if (isset($_POST['vscanupdate'])) {
+         $vscanupdate = strip_tags($_POST['vscanupdate']);
+         CreateBlockedArray($blocked,$warning,$excluded,$vscan,$vscanupdate,$filename);
          Header("Location: " . SM_PATH . "plugins/block_attach/options.php");
       }
 
