@@ -5,13 +5,16 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Block Attachments
-    Version ........ 0.3
+    Version ........ 0.4
     Purpose ........ Allows an admin to block any types of attachments
 
 *******************************************************************************/
 
-      global $squirrelmail_plugin_hooks;
-      $squirrelmail_plugin_hooks['optpage_register_block']['block_attach'] = 'block_attach_display_option';
+      global $squirrelmail_plugin_hooks, $plugins;
+      if (in_array('admin_options',$plugins))
+         $squirrelmail_plugin_hooks['admin_optpage_register_block']['block_attach'] = 'block_attach_display_option';
+      else
+         $squirrelmail_plugin_hooks['optpage_register_block']['block_attach'] = 'block_attach_display_option';
       $squirrelmail_plugin_hooks['attachment application/*']['block_attach'] = 'block_attach_block';
       $squirrelmail_plugin_hooks['attachment audio/*']['block_attach'] = 'block_attach_block';
       $squirrelmail_plugin_hooks['attachment chemical/*']['block_attach'] = 'block_attach_block';
