@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Block Attachments
-    Version ........ 0.3
+    Version ........ 0.4
     Purpose ........ Allows an admin to block any types of attachments
 
 *******************************************************************************/
@@ -20,11 +20,16 @@ require_once(SM_PATH . 'include/load_prefs.php');
 
 global $username;
 
-if (!function_exists('adm_check_user'))
-   include_once(SM_PATH . 'plugins/block_attach/includes/auth.php');
+$admins = array();
+$file = fopen(SM_PATH . 'config/admins',r);
+while (!feof($file)){
+   $x = trim(fgets($file));
+   if (strlen($x)>0)
+      $admins[]= $x;
+}
 
-$auth = adm_check_user();
-if (!$auth) header("Location " . SM_PATH . "index.php");
+$auth = in_array($username, $admins);
+if (!$auth) return;
 
 global $virusstrings;
 include_once(SM_PATH . "plugins/block_attach/includes/scan.php");
@@ -37,7 +42,8 @@ if (!file_exists($filename)) {
    $warning = Array('exe','com');
    $excluded = Array('');
    $virusscan = 1;
-   CreateBlockedArray($blocked,$warning,$excluded,$virusscan, $filename);
+   $virusscanupdate = 1;
+   CreateBlockedArray($blocked,$warning,$excluded,$virusscan,$virusscanupdate,$filename);
 }
 
 include_once($filename);
@@ -86,24 +92,34 @@ foreach($excluded as $value) {
 print "</select><br><input type=submit name=submit value='" . _("Remove") . "'></form></center></td></tr>\n";
 
 print "<tr><td colspan=4><hr width='100%' color='$color[9]'></td></tr>";
-print '<tr><td colspan=2><center><form method=post action="' . SM_PATH . 'plugins/block_attach/options.php">' . _("Virus Scan") . '&nbsp;&nbsp;<select name="vscan" size=1>';
-print '<option value=0';
+print '<tr><td colspan=2><center><form method=post action="' . SM_PATH . 'plugins/block_attach/options.php">' . _("Virus Scan") . '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
+print '<select name="vscan" size=1><option value=0';
 if ($virusscan == 0 || $virusscan == '')
    echo " SELECTED";
 print  '>' . _("Disabled") . '</option>';
 print '<option value=1';
 if ($virusscan == 1)
    echo " SELECTED";
-print  '>' . _("Enabled") . '</option></select><br><input type=submit value="' . _("Save") . '"></form></center></td><td><center>'. _("Currently scanning for") . '<br>'. count($virusstrings) . ' ' . _("viruses") . '</center></td></tr>';
+print  '>' . _("Enabled") . '</option></select><br>';
+print _("Auto Update") . '&nbsp;&nbsp;<select name="vscanupdate" size=1><option value=0';
+if ($virusscanupdate == 0 || $virusscanupdate == '')
+   echo " SELECTED";
+print  '>' . _("Disabled") . '</option>';
+print  '<option value=1';
+if ($virusscanupdate == 1)
+   echo " SELECTED";
+print  '>' . _("Enabled") . '</option></select>';
+print '<br><input type=submit value="' . _("Save") . '"></form></center></td><td><center>'. _("Currently scanning for") . '<br>'. count($virusstrings) . ' ' . _("viruses") . '</center></td></tr>';
 
 print "<tr><td colspan=4><hr width='100%' color='$color[9]'></td></tr>";
 print "</table></center>\n";
 
 textdomain('squirrelmail');
 
-function CreateBlockedArray($blocked, $warning, $excluded, $scan, $filename) {
+function CreateBlockedArray($blocked, $warning, $excluded, $scan, $update, $filename) {
    $string = "<?php\r\n\r\nglobal \$blocked;\r\n\r\n";
-   $string .= "\$virusscan = $scan;\r\n\r\n";
+   $string .= "\$virusscan = $scan;\r\n";
+   $string .= "\$virusscanupdate = $update;\r\n\r\n";
    $string .= "\$excluded = Array(";
    $string .= OutputBlockedArray($excluded);
    $string .= ");\r\n\r\n";
