@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Block Attachments
-    Version ........ 0.3
+    Version ........ 0.4
     Purpose ........ Allows an admin to block any types of attachments
 
 *******************************************************************************/
@@ -26,7 +26,7 @@
    }
 
    function block_attach_version() {
-      return 0.3;
+      return '0.4';
    }
 
 ?>
\ No newline at end of file
